from .base import PipelineBase as PipelineBase
from .base import StatsClientBase as StatsClientBase

class Pipeline(PipelineBase):
    def __init__(self, client) -> None: ...

class StatsClient(StatsClientBase):
    def __init__(
        self,
        host: str = "localhost",
        port: int = 8125,
        prefix: str | None = None,
        maxudpsize: int = 512,
        ipv6: bool = False,
    ) -> None: ...
    def close(self) -> None: ...
    def pipeline(self) -> Pipeline: ...



import types
from datetime import timedelta

from .timer import Timer as Timer

class StatsClientBase:
    def close(self) -> None: ...
    def pipeline(self) -> PipelineBase: ...
    def timer(self, stat: str, rate: int = 1) -> Timer: ...
    def timing(self, stat: str, delta: float | timedelta, rate: int = 1) -> None: ...
    def incr(self, stat: str, count: int = 1, rate: int = 1) -> None: ...
    def decr(self, stat: str, count: int = 1, rate: int = 1) -> None: ...
    def gauge(self, stat: str, value, rate: int = 1, delta: bool = False) -> None: ...
    def set(self, stat: str, value, rate: int = 1) -> None: ...

class PipelineBase(StatsClientBase):
    def __init__(self, client: StatsClientBase) -> None: ...
    def __enter__(self) -> PipelineBase: ...
    def __exit__(self, typ: type[BaseException] | None, value: BaseException | None, tb: types.TracebackType | None) -> None: ...
    def send(self) -> None: ...
    def pipeline(self) -> PipelineBase: ...



import types

from statsd.client.base import StatsClientBase

def safe_wraps(wrapper, *args, **kwargs): ...

class Timer:
    client: StatsClientBase
    stat: str
    rate: int
    ms: float
    def __init__(self, client: StatsClientBase, stat: str, rate: int = 1) -> None: ...
    def __call__(self, f): ...
    def __enter__(self) -> Timer: ...
    def __exit__(self, typ: type[BaseException] | None, value: BaseException | None, tb: types.TracebackType | None) -> None: ...
    def start(self) -> Timer: ...
    def stop(self, send: bool = True) -> Timer: ...
    def send(self) -> None: ...



from .client import StatsClient as StatsClient
from .client import TCPStatsClient as TCPStatsClient
from .client import UnixSocketStatsClient as UnixSocketStatsClient

__all__ = ["StatsClient", "TCPStatsClient", "UnixSocketStatsClient"]



from _typeshed import Incomplete

from .base import PipelineBase as PipelineBase
from .base import StatsClientBase as StatsClientBase

class StreamPipeline(PipelineBase): ...

class StreamClientBase(StatsClientBase):
    def connect(self) -> None: ...
    def close(self) -> None: ...
    def reconnect(self) -> None: ...
    def pipeline(self) -> StreamPipeline: ...

class TCPStatsClient(StreamClientBase):
    def __init__(
        self,
        host: str = "localhost",
        port: int = 8125,
        prefix: str | None = None,
        timeout: float | None = None,
        ipv6: bool = False,
    ) -> None: ...
    def connect(self) -> None: ...

class UnixSocketStatsClient(StreamClientBase):
    def __init__(self, socket_path, prefix: str | None = None, timeout: Incomplete | None = None) -> None: ...
    def connect(self) -> None: ...
